@@ -374,6 +374,11 @@ bool Application::IsShuttingDown()
 	return m_ShuttingDown;
 }
 
+bool Application::IsRestarting()
+{
+	return l_Restarting;
+}
+
 void Application::OnShutdown()
 {
 	/* Nothing to do here. */
@@ -722,6 +727,9 @@ void Application::SigIntTermHandler(int signum)
  */
 void Application::SigUsr1Handler(int)
 {
+	Log(LogInformation, "Application")
+		<< "Received USR1 signal, reopening application logs.";
+
 	RequestReopenLogs();
 }
 
