@@ -146,6 +146,8 @@ static Object::Ptr SerializeObject(const Object::Ptr& input, int attributeTypes,
 	DictionaryData fields;
 	fields.reserve(type->GetFieldCount() + 1);
 
+	ObjectLock olock(input);
+
 	for (int i = 0; i < type->GetFieldCount(); i++) {
 		Field field = type->GetFieldInfo(i);
 
@@ -157,7 +159,7 @@ static Object::Ptr SerializeObject(const Object::Ptr& input, int attributeTypes,
 
 		Value value = input->GetField(i);
 		stack.Push(field.Name, value);
-		fields.emplace_back(field.Name, SerializeInternal(input->GetField(i), attributeTypes, stack));
+		fields.emplace_back(field.Name, SerializeInternal(value, attributeTypes, stack));
 		stack.Pop();
 	}
 
