@@ -91,9 +91,9 @@ void TcpSocket::Bind(const String& node, const String& service, int family)
 
 		const int optTrue = 1;
 		setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, reinterpret_cast<const char *>(&optTrue), sizeof(optTrue));
-#ifndef _WIN32
+#ifdef SO_REUSEPORT
 		setsockopt(fd, SOL_SOCKET, SO_REUSEPORT, reinterpret_cast<const char *>(&optTrue), sizeof(optTrue));
-#endif /* _WIN32 */
+#endif /* SO_REUSEPORT */
 
 		int rc = bind(fd, info->ai_addr, info->ai_addrlen);
 
