@@ -236,13 +236,13 @@ int NodeSetupCommand::SetupMaster(const boost::program_options::variables_map& v
 	}
 
 	/* update constants.conf with NodeName = CN + TicketSalt = random value */
-	if (cn != Utility::GetFQDN()) {
+	if (endpointName != Utility::GetFQDN()) {
 		Log(LogWarning, "cli")
-			<< "CN '" << cn << "' does not match the default FQDN '" << Utility::GetFQDN() << "'. Requires update for NodeName constant in constants.conf!";
+			<< "CN/Endpoint name '" <<  endpointName << "' does not match the default FQDN '" << Utility::GetFQDN() << "'. Requires update for NodeName constant in constants.conf!";
 	}
 
-	NodeUtility::UpdateConstant("NodeName", cn);
-	NodeUtility::UpdateConstant("ZoneName", cn);
+	NodeUtility::UpdateConstant("NodeName", endpointName);
+	NodeUtility::UpdateConstant("ZoneName", zoneName);
 
 	String salt = RandomString(16);
 
@@ -536,13 +536,14 @@ int NodeSetupCommand::SetupNode(const boost::program_options::variables_map& vm,
 	NodeUtility::GenerateNodeIcingaConfig(endpointName, zoneName, parentZoneName, vm["endpoint"].as<std::vector<std::string> >(), globalZones);
 
 	/* update constants.conf with NodeName = CN */
-	if (cn != Utility::GetFQDN()) {
+	if (endpointName != Utility::GetFQDN()) {
 		Log(LogWarning, "cli")
-			<< "CN '" << cn << "' does not match the default FQDN '" << Utility::GetFQDN() << "'. Requires an update for the NodeName constant in constants.conf!";
+			<< "CN/Endpoint name '" << endpointName << "' does not match the default FQDN '"
+			<< Utility::GetFQDN() << "'. Requires an update for the NodeName constant in constants.conf!";
 	}
 
-	NodeUtility::UpdateConstant("NodeName", cn);
-	NodeUtility::UpdateConstant("ZoneName", vm["zone"].as<std::string>());
+	NodeUtility::UpdateConstant("NodeName", endpointName);
+	NodeUtility::UpdateConstant("ZoneName", zoneName);
 
 	if (!ticket.IsEmpty()) {
 		String ticketPath = ApiListener::GetCertsDir() + "/ticket";
