@@ -288,11 +288,9 @@ void Notification::BeginExecuteNotification(NotificationType type, const CheckRe
 					<< "': before specified begin time (" << Utility::FormatDuration(timesBegin) << ")";
 
 				/* we need to adjust the next notification time
-				 * to now + begin delaying the first notification
+				 * delaying the first notification
 				 */
-				double nextProposedNotification = now + timesBegin + 1.0;
-				if (GetNextNotification() > nextProposedNotification)
-					SetNextNotification(nextProposedNotification);
+				SetNextNotification(checkable->GetLastHardStateChange() + timesBegin + 1.0);
 
 				return;
 			}
@@ -317,6 +315,16 @@ void Notification::BeginExecuteNotification(NotificationType type, const CheckRe
 				<< "Not sending " << (reminder ? "reminder " : " ") << "notifications for notification object '" << GetName() << "': type '"
 				<< NotificationTypeToStringInternal(type) << "' does not match type filter: "
 				<< NotificationFilterToString(GetTypeFilter(), GetTypeFilterMap()) << ".";
+
+			/* Ensure to reset no_more_notifications on Recovery notifications,
+			 * even if the admin did not configure them in the filter.
+			 */
+			{
+				ObjectLock olock(this);
+				if (type == NotificationRecovery && GetInterval() <= 0)
+					SetNoMoreNotifications(false);
+			}
+
 			return;
 		}
 
