@@ -36,6 +36,12 @@
 #include "base/statsfunction.hpp"
 #include "base/exception.hpp"
 #include <fstream>
+#include <memory>
+#include <openssl/ssl.h>
+#include <openssl/tls1.h>
+#include <openssl/x509.h>
+#include <sstream>
+#include <utility>
 
 using namespace icinga;
 
@@ -246,7 +252,6 @@ void ApiListener::Start(bool runtimeCreated)
 
 	{
 		boost::mutex::scoped_lock lock(m_LogLock);
-		RotateLogFile();
 		OpenLogFile();
 	}
 
@@ -293,6 +298,7 @@ void ApiListener::Stop(bool runtimeDeleted)
 	{
 		boost::mutex::scoped_lock lock(m_LogLock);
 		CloseLogFile();
+		RotateLogFile();
 	}
 
 	RemoveStatusFile();
@@ -694,11 +700,19 @@ void ApiListener::ApiTimerHandler()
 
 	for (int ts : files) {
 		bool need = false;
+		auto localZone (GetLocalEndpoint()->GetZone());
 
 		for (const Endpoint::Ptr& endpoint : ConfigType::GetObjectsByType<Endpoint>()) {
 			if (endpoint == GetLocalEndpoint())
 				continue;
 
+			auto zone (endpoint->GetZone());
+
+			/* only care for endpoints in a) the same zone b) our parent zone c) immediate child zones */
+			if (!(zone == localZone || zone == localZone->GetParent() || zone->GetParent() == localZone)) {
+				continue;
+			}
+
 			if (endpoint->GetLogDuration() >= 0 && ts < now - endpoint->GetLogDuration())
 				continue;
 
@@ -1087,13 +1101,11 @@ void ApiListener::RotateLogFile()
 	String oldpath = GetApiDir() + "log/current";
 	String newpath = GetApiDir() + "log/" + Convert::ToString(static_cast<int>(ts)+1);
 
-
-#ifdef _WIN32
-	_unlink(newpath.CStr());
-#endif /* _WIN32 */
-
-
-	(void) rename(oldpath.CStr(), newpath.CStr());
+	// If the log is being rotated more than once per second,
+	// don't overwrite the previous one, but silently deny rotation.
+	if (!Utility::PathExists(newpath)) {
+		(void) rename(oldpath.CStr(), newpath.CStr());
+	}
 }
 
 void ApiListener::LogGlobHandler(std::vector<int>& files, const String& file)
@@ -1146,7 +1158,6 @@ void ApiListener::ReplayLog(const JsonRpcConnection::Ptr& client)
 		boost::mutex::scoped_lock lock(m_LogLock);
 
 		CloseLogFile();
-		RotateLogFile();
 
 		if (count == -1 || count > 50000) {
 			OpenLogFile();
@@ -1161,16 +1172,21 @@ void ApiListener::ReplayLog(const JsonRpcConnection::Ptr& client)
 		Utility::Glob(GetApiDir() + "log/*", std::bind(&ApiListener::LogGlobHandler, std::ref(files), _1), GlobFile);
 		std::sort(files.begin(), files.end());
 
+		std::vector<std::pair<int, String>> allFiles;
+
 		for (int ts : files) {
-			String path = GetApiDir() + "log/" + Convert::ToString(ts);
+			if (ts >= peer_ts) {
+				allFiles.emplace_back(ts, GetApiDir() + "log/" + Convert::ToString(ts));
+			}
+		}
 
-			if (ts < peer_ts)
-				continue;
+		allFiles.emplace_back(Utility::GetTime() + 1, GetApiDir() + "log/current");
 
+		for (auto& file : allFiles) {
 			Log(LogNotice, "ApiListener")
-				<< "Replaying log: " << path;
+				<< "Replaying log: " << file.second;
 
-			auto *fp = new std::fstream(path.CStr(), std::fstream::in | std::fstream::binary);
+			auto *fp = new std::fstream(file.second.CStr(), std::fstream::in | std::fstream::binary);
 			StdioStream::Ptr logStream = new StdioStream(fp, true);
 
 			String message;
@@ -1190,7 +1206,7 @@ void ApiListener::ReplayLog(const JsonRpcConnection::Ptr& client)
 					pmessage = JsonDecode(message);
 				} catch (const std::exception&) {
 					Log(LogWarning, "ApiListener")
-						<< "Unexpected end-of-file for cluster log: " << path;
+						<< "Unexpected end-of-file for cluster log: " << file.second;
 
 					/* Log files may be incomplete or corrupted. This is perfectly OK. */
 					break;
@@ -1227,8 +1243,8 @@ void ApiListener::ReplayLog(const JsonRpcConnection::Ptr& client)
 
 				peer_ts = pmessage->Get("timestamp");
 
-				if (ts > logpos_ts + 10) {
-					logpos_ts = ts;
+				if (file.first > logpos_ts + 10) {
+					logpos_ts = file.first;
 
 					Dictionary::Ptr lmessage = new Dictionary({
 						{ "jsonrpc", "2.0" },
@@ -1250,9 +1266,10 @@ void ApiListener::ReplayLog(const JsonRpcConnection::Ptr& client)
 			Log(LogInformation, "ApiListener")
 				<< "Replayed " << count << " messages.";
 		}
-
-		Log(LogNotice, "ApiListener")
-			<< "Replayed " << count << " messages.";
+		else {
+			Log(LogNotice, "ApiListener")
+				<< "Replayed " << count << " messages.";
+		}
 
 		if (last_sync) {
 			{
