@@ -106,6 +106,8 @@ bool FilterUtility::EvaluateFilter(ScriptFrame& frame, Expression *filter,
 		ASSERT(frame.Self.IsObjectType<Namespace>());
 
 		frameNS = frame.Self;
+
+		ASSERT(frameNS != ScriptGlobal::GetGlobals());
 	}
 
 	frameNS->Set("obj", target);
@@ -171,7 +173,7 @@ void FilterUtility::CheckPermission(const ApiUser::Ptr& user, const String& perm
 
 			if (filter && permissionFilter) {
 				std::vector<std::unique_ptr<Expression> > args;
-				args.emplace_back(new GetScopeExpression(ScopeLocal));
+				args.emplace_back(new GetScopeExpression(ScopeThis));
 				std::unique_ptr<Expression> indexer{new IndexerExpression(std::unique_ptr<Expression>(MakeLiteral(filter)), std::unique_ptr<Expression>(MakeLiteral("call")))};
 				FunctionCallExpression *fexpr = new FunctionCallExpression(std::move(indexer), std::move(args));
 
@@ -205,7 +207,8 @@ std::vector<Value> FilterUtility::GetFilterTargets(const QueryDescription& qd, c
 	Expression *permissionFilter;
 	CheckPermission(user, qd.Permission, &permissionFilter);
 
-	ScriptFrame permissionFrame(true);
+	Namespace::Ptr permissionFrameNS = new Namespace();
+	ScriptFrame permissionFrame(false, permissionFrameNS);
 
 	for (const String& type : qd.Types) {
 		String attr = type;
@@ -255,9 +258,9 @@ std::vector<Value> FilterUtility::GetFilterTargets(const QueryDescription& qd, c
 		if (qd.Types.find(type) == qd.Types.end())
 			BOOST_THROW_EXCEPTION(std::invalid_argument("Invalid type specified for this query."));
 
-		ScriptFrame frame(true);
-		frame.Sandboxed = true;
 		Namespace::Ptr frameNS = new Namespace();
+		ScriptFrame frame(false, frameNS);
+		frame.Sandboxed = true;
 
 		if (query->Contains("filter")) {
 			String filter = HttpUtility::GetLastParameter(query, "filter");
@@ -271,8 +274,6 @@ std::vector<Value> FilterUtility::GetFilterTargets(const QueryDescription& qd, c
 				}
 			}
 
-			frame.Self = frameNS;
-
 			provider->FindTargets(type, std::bind(&FilteredAddTarget,
 				std::ref(permissionFrame), permissionFilter,
 				std::ref(frame), &*ufilter, std::ref(result), variableName, _1));
